/* Copyright (C) 2008 Igor V. Burago */

#include <map>
#include <vector>
#include <cassert>
#include "Check"

using namespace std;
using namespace Check;


int width;
int height;
map<int, int> horLink;
map<int, int> verLink;
vector< vector<char> > field;


inline bool inside(const int row, const int col)
{
    return 0 <= row && row < height && 0 <= col && col < width;
}


bool reflect(const int row, const int col, const bool isHor)
{
    const int base = (isHor ? row : col);
    map<int, int> &linksMap = (isHor ? horLink : verLink);
    if (linksMap.find(base) == linksMap.end())
        return true; /* This cell is not constrained, so it cannot be wrong */
    const int newRow = isHor * row + !isHor * (2 * linksMap[base] - row);
    const int newCol = !isHor * col + isHor * (2 * linksMap[base] - col);
    return inside(newRow, newCol) && field[newRow][newCol] == '#';
}


int main(int argc, char *argv[])
{
    init(argc, argv);

    input >> width >> height >> eatLine;
    for (int row = 0; row < height; ++row)
    {
        string line;
        input.getLine(line);
        for (int col = 0; col < width; ++col)
        {
            char symbol = line[col];
            switch (symbol)
            {
                case '+':
                case '-':
                {
                    verLink[col] = row;
                    if (symbol != '+')
                        break;
                } /* fallthrough */
                case '|': horLink[row] = col; break;
                default: assert(symbol == '.'); break;
            }
        }
    }

    bool noneSolution = true;
    try
    {
        // NOTE: The checker completely rely upon answer file's correctness
        answer >> ensure("NONE");
    }
    catch (const UnhopedDataError &error)
    {
        noneSolution = false;
    }

    if (!noneSolution)
    {
        field.resize(height);
        for (int row = 0; row < height; ++row)
        {
            field[row].resize(width, '\0');
            string line;
            output.getLine(line);
            for (int col = 0; col < width; ++col)
            {
                char symbol = line[col];
                exitUnless(
                    symbol == '.' || symbol == '#',
                    PresentationError, "Invalid symbol \'%c\'", symbol);
                field[row][col] = symbol;
            }
        }

        for (int row = 0; row < height; ++row)
            for (int col = 0; col < width; ++col)
                if (field[row][col] == '#')
                    exitUnless(
                        reflect(row, col, true) && reflect(row, col, false),
                        WrongAnswer, "Cell (%d, %d) does not satisfy a constraint",
                        row + 1, col + 1);
    }
    else
        output >> ensure("NONE");

    quit(SolutionAccepted);
}
