/* Copyright (C) 2008 Igor V. Burago */

#include <cstdio>
#include <string>
#include <vector>
#include <algorithm>
#include "easygen.h"
#include "easygen.cpp"

using namespace std;


const int MaxLinksCount = 100;

int width;
int height;
vector<string> field;


void fillLink(const int row, const int col, const bool isHor)
{
    const int base = (isHor ? col : row);
    const int limit = (isHor ? width : height);
    const int size = (isHor ? min(col, width - col - 1) : min(row, height - row - 1));
    for (int pos = 0; pos < limit; ++pos)
        if (pos < base - size || base + size < pos)
        {
            int newRow = isHor * row + !isHor * pos;
            int newCol = !isHor * col + isHor * pos;
            field[newRow][newCol] = 'X';
        }
}


int main(int argc, char *argv[])
{
    try
    {
        testInfo test(argc, argv);

        width = test["width"];
        height = test["height"];
        sscanf(argv[1], "%d", &width);
        sscanf(argv[2], "%d", &height);
        field.resize(height);
        for (int row = 0; row < height; ++row)
            field[row].resize(width, '.');

        int totalCount = min(max(1, width * height / 10), MaxLinksCount);
        int horCount = genRandInt(1, totalCount);
        int verCount = totalCount - horCount;
        for (int row = 0; row < height; ++row)
            if (genRandInt(0, height - row - 1) < horCount)
            {
                int col = genRandInt(0, width - 1);
                field[row][col] = (field[row][col] == '.' ? '|' : '+');
                --horCount;
            }
        for (int col = 0; col < width; ++col)
            if (genRandInt(0, width - col - 1) < verCount)
            {
                int row = genRandInt(0, height - 1);
                field[row][col] = (field[row][col] == '.' ? '-' : '+');
                --verCount;
            }

        for (int row = 0; row < height; ++row)
            test["field"][row + 1]["row"] = field[row];
    }
    catch (genError error)
    {
        puts(error.err().c_str());
    }

    return 0;
}
