/* Copyright (C) 2008 Igor V. Burago */

#include <cstdio>
#include <cstdlib>
#include <cassert>
#include <map>
#include <vector>
#include <algorithm>

using namespace std;


int width;
int height;
map<int, int> horLink;
map<int, int> verLink;
vector< vector<char> > field;


inline void quitIf(const bool cond)
{
    if (cond)
    {
        puts("NONE");
        exit(0);
    }
}


inline bool inside(const int row, const int col)
{
    return 0 <= row && row < height && 0 <= col && col < width;
}


bool reflect(const int row, const int col, const bool isHor, int *newRow, int *newCol)
{
    const int base = (isHor ? row : col);
    map<int, int> &linksMap = (isHor ? horLink : verLink);
    if (linksMap.find(base) == linksMap.end())
        return false;
    *newRow = isHor * row + !isHor * (2 * linksMap[base] - row);
    *newCol = !isHor * col + isHor * (2 * linksMap[base] - col);
    return inside(*newRow, *newCol) && field[*newRow][*newCol] != 'X';
}


void fillLink(const int row, const int col, const bool isHor)
{
    const int base = (isHor ? col : row);
    const int limit = (isHor ? width : height);
    const int size = (isHor ? min(col, width - col - 1) : min(row, height - row - 1));
    for (int pos = 0; pos < limit; ++pos)
        if (pos < base - size || base + size < pos)
        {
            bool newHor = !isHor;
            int newRow = isHor * row + !isHor * pos;
            int newCol = !isHor * col + isHor * pos;
            field[newRow][newCol] = 'X';
            while (reflect(newRow, newCol, newHor, &newRow, &newCol))
            {
                field[newRow][newCol] = 'X';
                newHor = !newHor;
            }
        }
}


int putLink(const int row, const int col, const bool isHor)
{
    int stonesCount = 0;
    const int size = (isHor ? min(col, width - col - 1) : min(row, height - row - 1));
    for (int offset = 0; offset <= size; ++offset)
    {
        const int newRow = row + !isHor * offset;
        const int newCol = col + isHor * offset;
        int refRow;
        int refCol;
        reflect(newRow, newCol, isHor, &refRow, &refCol);
        if (field[newRow][newCol] != 'X')
        {
            field[newRow][newCol] = field[refRow][refCol] = '#';
            stonesCount += 2;
        }
    }
    return stonesCount;
}


const int MaxFieldSize = 100;
const int MaxLinksCount = 100;


int main()
{
    freopen("input.txt", "rt", stdin);
    freopen("output.txt", "wt", stdout);

    scanf("%d%d\n", &width, &height);
    assert(1 <= width && width <= MaxFieldSize);
    assert(1 <= height && height <= MaxFieldSize);

    for (int row = 0; row < height; ++row)
        for (int col = 0; col < width; ++col)
        {
            char symbol;
            scanf("%c ", &symbol);
            switch (symbol)
            {
                case '+':
                case '-':
                {
                    quitIf(verLink.find(col) != verLink.end());
                    verLink[col] = row;
                    if (symbol != '+')
                        break;
                } /* fallthrough */
                case '|':
                {
                    quitIf(horLink.find(row) != horLink.end());
                    horLink[row] = col;
                } break;
                default: assert(symbol == '.'); break;
            }
        }
    int linksCount = horLink.size() + verLink.size();
    assert(1 <= linksCount && linksCount <= MaxLinksCount);

    field.resize(height);
    for (int row = 0; row < height; ++row)
        field[row].resize(width, '.');

    map<int, int>::const_iterator pos;
    for (pos = horLink.begin(); pos != horLink.end(); ++pos)
        fillLink(pos->first, pos->second, true);
    for (pos = verLink.begin(); pos != verLink.end(); ++pos)
        fillLink(pos->second, pos->first, false);
    for (pos = horLink.begin(); pos != horLink.end(); ++pos)
        quitIf(putLink(pos->first, pos->second, true) == 0);
    for (pos = verLink.begin(); pos != verLink.end(); ++pos)
        quitIf(putLink(pos->second, pos->first, false) == 0);

    for (int row = 0; row < height; ++row)
    {
        for (int col = 0; col < width; ++col)
            putchar(field[row][col] == 'X' ? '.' : field[row][col]);
        putchar('\n');
    }

    return 0;
}
